@@ -27,8 +27,8 @@ def is_last(lst: tp.Iterable[T]) -> tp.Generator[tp.Tuple[bool, T], None, None]:
     yield True, ret_var
 
 
-def add_next(lst: tp.Iterable[T], wrap_over: bool = False) -> tp.Generator[
-    tp.Tuple[T, tp.Optional[T]], None, None]:
+def add_next(lst: tp.Iterable[T], wrap_over: bool = False, skip_last: bool = False) -> tp.Iterator[
+        tp.Tuple[T, tp.Optional[T]]]:
     """
     Yields a 2-tuple of given iterable, presenting the next element as second element of the tuple.
 
@@ -43,6 +43,7 @@ def add_next(lst: tp.Iterable[T], wrap_over: bool = False) -> tp.Generator[
     :param lst: iterable to iterate over
     :param wrap_over: whether to attach the first element to the pair of the last element instead
         of None
+    :param skip_last: if this is True, then last element, alongside with a None, won't be output
     """
     iterator = iter(lst)
     try:
@@ -55,7 +56,8 @@ def add_next(lst: tp.Iterable[T], wrap_over: bool = False) -> tp.Generator[
     if wrap_over:
         yield prev_val, first_val
     else:
-        yield prev_val, None
+        if not skip_last:
+            yield prev_val, None
 
 
 def half_product(seq1: tp.Iterable[T], seq2: tp.Iterable[U]) -> tp.Generator[
