@@ -1,8 +1,3 @@
-import logging
-
-logger = logging.getLogger(__name__)
-
-
 def HashableWrapper(obj):
     """
     A decorator that makes given objects hashable by their id.
